# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkContourSpatialObjectPython
else:
    import _itkContourSpatialObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkContourSpatialObjectPointPython
import itk.itkSpatialObjectPointPython
import itk.itkSpatialObjectBasePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkBoundingBoxPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
import itk.itkArrayPython
import itk.itkMapContainerPython
import itk.itkSpatialObjectPropertyPython
import itk.itkRGBAPixelPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkArray2DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkDiffusionTensor3DPython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.itkMatrixOffsetTransformBasePython
class listitkPointBasedSpatialObjectContour2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkPointBasedSpatialObjectContour2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkPointBasedSpatialObjectContour2_Pointer

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type
        v: std::list< itkPointBasedSpatialObjectContour2_Pointer,std::allocator< itkPointBasedSpatialObjectContour2_Pointer > > const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkPointBasedSpatialObjectContour2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkPointBasedSpatialObjectContour2_Pointer,std::allocator< itkPointBasedSpatialObjectContour2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour2_Pointer >::difference_type
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkPointBasedSpatialObjectContour2_Pointer > &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::allocator_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator
        last: std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkPointBasedSpatialObjectContour2_Pointer
        __init__(self, other) -> listitkPointBasedSpatialObjectContour2_Pointer

        Parameters
        ----------
        other: std::list< itkPointBasedSpatialObjectContour2_Pointer > const &

        __init__(self, size) -> listitkPointBasedSpatialObjectContour2_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type

        __init__(self, size, value) -> listitkPointBasedSpatialObjectContour2_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type
        value: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_swiginit(self, _itkContourSpatialObjectPython.new_listitkPointBasedSpatialObjectContour2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectContour2_Pointer >::iterator
        n: std::list< itkPointBasedSpatialObjectContour2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectContour2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_reverse(self)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_listitkPointBasedSpatialObjectContour2_Pointer

# Register listitkPointBasedSpatialObjectContour2_Pointer in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour2_Pointer_swigregister(listitkPointBasedSpatialObjectContour2_Pointer)
class listitkPointBasedSpatialObjectContour3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkPointBasedSpatialObjectContour3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkPointBasedSpatialObjectContour3_Pointer

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type
        v: std::list< itkPointBasedSpatialObjectContour3_Pointer,std::allocator< itkPointBasedSpatialObjectContour3_Pointer > > const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkPointBasedSpatialObjectContour3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkPointBasedSpatialObjectContour3_Pointer,std::allocator< itkPointBasedSpatialObjectContour3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectContour3_Pointer >::difference_type
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkPointBasedSpatialObjectContour3_Pointer > &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::allocator_type"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator
        last: std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkPointBasedSpatialObjectContour3_Pointer
        __init__(self, other) -> listitkPointBasedSpatialObjectContour3_Pointer

        Parameters
        ----------
        other: std::list< itkPointBasedSpatialObjectContour3_Pointer > const &

        __init__(self, size) -> listitkPointBasedSpatialObjectContour3_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type

        __init__(self, size, value) -> listitkPointBasedSpatialObjectContour3_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type
        value: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_swiginit(self, _itkContourSpatialObjectPython.new_listitkPointBasedSpatialObjectContour3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectContour3_Pointer >::iterator
        n: std::list< itkPointBasedSpatialObjectContour3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectContour3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_reverse(self)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_listitkPointBasedSpatialObjectContour3_Pointer

# Register listitkPointBasedSpatialObjectContour3_Pointer in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.listitkPointBasedSpatialObjectContour3_Pointer_swigregister(listitkPointBasedSpatialObjectContour3_Pointer)
class listitkContourSpatialObject2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkContourSpatialObject2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkContourSpatialObject2_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkContourSpatialObject2_Pointer

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type
        j: std::list< itkContourSpatialObject2_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type
        j: std::list< itkContourSpatialObject2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type
        j: std::list< itkContourSpatialObject2_Pointer >::difference_type
        v: std::list< itkContourSpatialObject2_Pointer,std::allocator< itkContourSpatialObject2_Pointer > > const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type
        j: std::list< itkContourSpatialObject2_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkContourSpatialObject2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkContourSpatialObject2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkContourSpatialObject2_Pointer,std::allocator< itkContourSpatialObject2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject2_Pointer >::difference_type
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkContourSpatialObject2_Pointer >::value_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkContourSpatialObject2_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkContourSpatialObject2_Pointer > &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkContourSpatialObject2_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkContourSpatialObject2_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkContourSpatialObject2_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkContourSpatialObject2_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkContourSpatialObject2_Pointer >::allocator_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkContourSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkContourSpatialObject2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkContourSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkContourSpatialObject2_Pointer >::iterator
        last: std::list< itkContourSpatialObject2_Pointer >::iterator

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkContourSpatialObject2_Pointer
        __init__(self, other) -> listitkContourSpatialObject2_Pointer

        Parameters
        ----------
        other: std::list< itkContourSpatialObject2_Pointer > const &

        __init__(self, size) -> listitkContourSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkContourSpatialObject2_Pointer >::size_type

        __init__(self, size, value) -> listitkContourSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkContourSpatialObject2_Pointer >::size_type
        value: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_swiginit(self, _itkContourSpatialObjectPython.new_listitkContourSpatialObject2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkContourSpatialObject2_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkContourSpatialObject2_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkContourSpatialObject2_Pointer >::size_type
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkContourSpatialObject2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkContourSpatialObject2_Pointer >::size_type
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkContourSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkContourSpatialObject2_Pointer >::iterator
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkContourSpatialObject2_Pointer >::iterator
        n: std::list< itkContourSpatialObject2_Pointer >::size_type
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkContourSpatialObject2_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_reverse(self)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_listitkContourSpatialObject2_Pointer

# Register listitkContourSpatialObject2_Pointer in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.listitkContourSpatialObject2_Pointer_swigregister(listitkContourSpatialObject2_Pointer)
class listitkContourSpatialObject3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkContourSpatialObject3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkContourSpatialObject3_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkContourSpatialObject3_Pointer

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type
        j: std::list< itkContourSpatialObject3_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type
        j: std::list< itkContourSpatialObject3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type
        j: std::list< itkContourSpatialObject3_Pointer >::difference_type
        v: std::list< itkContourSpatialObject3_Pointer,std::allocator< itkContourSpatialObject3_Pointer > > const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type
        j: std::list< itkContourSpatialObject3_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkContourSpatialObject3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkContourSpatialObject3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkContourSpatialObject3_Pointer,std::allocator< itkContourSpatialObject3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkContourSpatialObject3_Pointer >::difference_type
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkContourSpatialObject3_Pointer >::value_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkContourSpatialObject3_Pointer >::size_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkContourSpatialObject3_Pointer > &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkContourSpatialObject3_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkContourSpatialObject3_Pointer >::iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkContourSpatialObject3_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkContourSpatialObject3_Pointer >::reverse_iterator"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkContourSpatialObject3_Pointer >::allocator_type"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkContourSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkContourSpatialObject3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkContourSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkContourSpatialObject3_Pointer >::iterator
        last: std::list< itkContourSpatialObject3_Pointer >::iterator

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkContourSpatialObject3_Pointer
        __init__(self, other) -> listitkContourSpatialObject3_Pointer

        Parameters
        ----------
        other: std::list< itkContourSpatialObject3_Pointer > const &

        __init__(self, size) -> listitkContourSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkContourSpatialObject3_Pointer >::size_type

        __init__(self, size, value) -> listitkContourSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkContourSpatialObject3_Pointer >::size_type
        value: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_swiginit(self, _itkContourSpatialObjectPython.new_listitkContourSpatialObject3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkContourSpatialObject3_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkContourSpatialObject3_Pointer >::value_type const &"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkContourSpatialObject3_Pointer >::size_type
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkContourSpatialObject3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkContourSpatialObject3_Pointer >::size_type
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkContourSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkContourSpatialObject3_Pointer >::iterator
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkContourSpatialObject3_Pointer >::iterator
        n: std::list< itkContourSpatialObject3_Pointer >::size_type
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkContourSpatialObject3_Pointer >::value_type const &

        """
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_reverse(self)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_listitkContourSpatialObject3_Pointer

# Register listitkContourSpatialObject3_Pointer in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.listitkContourSpatialObject3_Pointer_swigregister(listitkContourSpatialObject3_Pointer)
class itkContourSpatialObjectEnums(object):
    r"""Proxy of C++ itkContourSpatialObjectEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    InterpolationMethod_NO_INTERPOLATION = _itkContourSpatialObjectPython.itkContourSpatialObjectEnums_InterpolationMethod_NO_INTERPOLATION
    
    InterpolationMethod_EXPLICIT_INTERPOLATION = _itkContourSpatialObjectPython.itkContourSpatialObjectEnums_InterpolationMethod_EXPLICIT_INTERPOLATION
    
    InterpolationMethod_BEZIER_INTERPOLATION = _itkContourSpatialObjectPython.itkContourSpatialObjectEnums_InterpolationMethod_BEZIER_INTERPOLATION
    
    InterpolationMethod_LINEAR_INTERPOLATION = _itkContourSpatialObjectPython.itkContourSpatialObjectEnums_InterpolationMethod_LINEAR_INTERPOLATION
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkContourSpatialObjectEnums
        __init__(self, arg0) -> itkContourSpatialObjectEnums

        Parameters
        ----------
        arg0: itkContourSpatialObjectEnums const &

        """
        _itkContourSpatialObjectPython.itkContourSpatialObjectEnums_swiginit(self, _itkContourSpatialObjectPython.new_itkContourSpatialObjectEnums(*args))
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_itkContourSpatialObjectEnums

# Register itkContourSpatialObjectEnums in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.itkContourSpatialObjectEnums_swigregister(itkContourSpatialObjectEnums)

def itkPointBasedSpatialObjectContour2_New():
    return itkPointBasedSpatialObjectContour2.New()

class itkPointBasedSpatialObjectContour2(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkPointBasedSpatialObjectContour2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPointBasedSpatialObjectContour2_Pointer"""
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPointBasedSpatialObjectContour2_Pointer"""
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_Clone(self)

    def AddPoint(self, newPoint):
        r"""
        AddPoint(self, newPoint)

        Parameters
        ----------
        newPoint: itkContourSpatialObjectPoint2 const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_AddPoint(self, newPoint)

    def RemovePoint(self, id):
        r"""
        RemovePoint(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_RemovePoint(self, id)

    def SetPoints(self, newPoints):
        r"""
        SetPoints(self, newPoints)

        Parameters
        ----------
        newPoints: std::vector< itkContourSpatialObjectPoint2,std::allocator< itkContourSpatialObjectPoint2 > > const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_SetPoints(self, newPoints)

    def GetPoints(self, *args):
        r"""
        GetPoints(self) -> vectoritkContourSpatialObjectPoint2
        GetPoints(self) -> vectoritkContourSpatialObjectPoint2
        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_GetPoints(self, *args)

    def GetPoint(self, *args):
        r"""
        GetPoint(self, id) -> itkContourSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        GetPoint(self, id) -> itkContourSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_GetPoint(self, *args)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned long"""
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_GetNumberOfPoints(self)

    def ClosestPointInWorldSpace(self, point):
        r"""
        ClosestPointInWorldSpace(self, point) -> itkContourSpatialObjectPoint2

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_ClosestPointInWorldSpace(self, point)

    def ClosestPointInObjectSpace(self, point):
        r"""
        ClosestPointInObjectSpace(self, point) -> itkContourSpatialObjectPoint2

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_ClosestPointInObjectSpace(self, point)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_itkPointBasedSpatialObjectContour2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointBasedSpatialObjectContour2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPointBasedSpatialObjectContour2

        Create a new object of the class itkPointBasedSpatialObjectContour2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPointBasedSpatialObjectContour2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPointBasedSpatialObjectContour2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPointBasedSpatialObjectContour2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPointBasedSpatialObjectContour2 in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour2_swigregister(itkPointBasedSpatialObjectContour2)

def itkPointBasedSpatialObjectContour3_New():
    return itkPointBasedSpatialObjectContour3.New()

class itkPointBasedSpatialObjectContour3(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkPointBasedSpatialObjectContour3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPointBasedSpatialObjectContour3_Pointer"""
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPointBasedSpatialObjectContour3_Pointer"""
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_Clone(self)

    def AddPoint(self, newPoint):
        r"""
        AddPoint(self, newPoint)

        Parameters
        ----------
        newPoint: itkContourSpatialObjectPoint3 const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_AddPoint(self, newPoint)

    def RemovePoint(self, id):
        r"""
        RemovePoint(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_RemovePoint(self, id)

    def SetPoints(self, newPoints):
        r"""
        SetPoints(self, newPoints)

        Parameters
        ----------
        newPoints: std::vector< itkContourSpatialObjectPoint3,std::allocator< itkContourSpatialObjectPoint3 > > const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_SetPoints(self, newPoints)

    def GetPoints(self, *args):
        r"""
        GetPoints(self) -> vectoritkContourSpatialObjectPoint3
        GetPoints(self) -> vectoritkContourSpatialObjectPoint3
        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_GetPoints(self, *args)

    def GetPoint(self, *args):
        r"""
        GetPoint(self, id) -> itkContourSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        GetPoint(self, id) -> itkContourSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_GetPoint(self, *args)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned long"""
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_GetNumberOfPoints(self)

    def ClosestPointInWorldSpace(self, point):
        r"""
        ClosestPointInWorldSpace(self, point) -> itkContourSpatialObjectPoint3

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_ClosestPointInWorldSpace(self, point)

    def ClosestPointInObjectSpace(self, point):
        r"""
        ClosestPointInObjectSpace(self, point) -> itkContourSpatialObjectPoint3

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_ClosestPointInObjectSpace(self, point)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_itkPointBasedSpatialObjectContour3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointBasedSpatialObjectContour3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPointBasedSpatialObjectContour3

        Create a new object of the class itkPointBasedSpatialObjectContour3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPointBasedSpatialObjectContour3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPointBasedSpatialObjectContour3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPointBasedSpatialObjectContour3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPointBasedSpatialObjectContour3 in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.itkPointBasedSpatialObjectContour3_swigregister(itkPointBasedSpatialObjectContour3)

def itkContourSpatialObject2_New():
    return itkContourSpatialObject2.New()

class itkContourSpatialObject2(itkPointBasedSpatialObjectContour2):
    r"""Proxy of C++ itkContourSpatialObject2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkContourSpatialObject2_Pointer"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkContourSpatialObject2_Pointer"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_Clone(self)

    def GetControlPoints(self, *args):
        r"""
        GetControlPoints(self) -> vectoritkContourSpatialObjectPoint2
        GetControlPoints(self) -> vectoritkContourSpatialObjectPoint2
        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetControlPoints(self, *args)

    def SetControlPoints(self, points):
        r"""
        SetControlPoints(self, points)

        Parameters
        ----------
        points: std::vector< itkContourSpatialObjectPoint2,std::allocator< itkContourSpatialObjectPoint2 > > const &

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_SetControlPoints(self, points)

    def AddControlPoint(self, point):
        r"""
        AddControlPoint(self, point)

        Parameters
        ----------
        point: itkContourSpatialObjectPoint2 const &

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_AddControlPoint(self, point)

    def GetControlPoint(self, *args):
        r"""
        GetControlPoint(self, id) -> itkContourSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        GetControlPoint(self, id) -> itkContourSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetControlPoint(self, *args)

    def GetNumberOfControlPoints(self):
        r"""GetNumberOfControlPoints(self) -> unsigned long"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetNumberOfControlPoints(self)

    def SetInterpolationMethod(self, _arg):
        r"""
        SetInterpolationMethod(self, _arg)

        Parameters
        ----------
        _arg: enum itkContourSpatialObjectEnums::InterpolationMethod const

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_SetInterpolationMethod(self, _arg)

    def GetInterpolationMethod(self):
        r"""GetInterpolationMethod(self) -> itkContourSpatialObjectEnums::InterpolationMethod"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetInterpolationMethod(self)

    def SetInterpolationFactor(self, _arg):
        r"""
        SetInterpolationFactor(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_SetInterpolationFactor(self, _arg)

    def GetInterpolationFactor(self):
        r"""GetInterpolationFactor(self) -> unsigned int"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetInterpolationFactor(self)

    def SetIsClosed(self, _arg):
        r"""
        SetIsClosed(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_SetIsClosed(self, _arg)

    def GetIsClosed(self):
        r"""GetIsClosed(self) -> bool"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetIsClosed(self)

    def IsClosedOn(self):
        r"""IsClosedOn(self)"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_IsClosedOn(self)

    def IsClosedOff(self):
        r"""IsClosedOff(self)"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_IsClosedOff(self)

    def GetOrientationInObjectSpace(self):
        r"""GetOrientationInObjectSpace(self) -> int"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetOrientationInObjectSpace(self)

    def SetAttachedToSlice(self, _arg):
        r"""
        SetAttachedToSlice(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_SetAttachedToSlice(self, _arg)

    def GetAttachedToSlice(self):
        r"""GetAttachedToSlice(self) -> int"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_GetAttachedToSlice(self)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_itkContourSpatialObject2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkContourSpatialObject2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkContourSpatialObject2

        Create a new object of the class itkContourSpatialObject2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkContourSpatialObject2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkContourSpatialObject2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkContourSpatialObject2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkContourSpatialObject2 in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.itkContourSpatialObject2_swigregister(itkContourSpatialObject2)

def itkContourSpatialObject3_New():
    return itkContourSpatialObject3.New()

class itkContourSpatialObject3(itkPointBasedSpatialObjectContour3):
    r"""Proxy of C++ itkContourSpatialObject3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkContourSpatialObject3_Pointer"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkContourSpatialObject3_Pointer"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_Clone(self)

    def GetControlPoints(self, *args):
        r"""
        GetControlPoints(self) -> vectoritkContourSpatialObjectPoint3
        GetControlPoints(self) -> vectoritkContourSpatialObjectPoint3
        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetControlPoints(self, *args)

    def SetControlPoints(self, points):
        r"""
        SetControlPoints(self, points)

        Parameters
        ----------
        points: std::vector< itkContourSpatialObjectPoint3,std::allocator< itkContourSpatialObjectPoint3 > > const &

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_SetControlPoints(self, points)

    def AddControlPoint(self, point):
        r"""
        AddControlPoint(self, point)

        Parameters
        ----------
        point: itkContourSpatialObjectPoint3 const &

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_AddControlPoint(self, point)

    def GetControlPoint(self, *args):
        r"""
        GetControlPoint(self, id) -> itkContourSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        GetControlPoint(self, id) -> itkContourSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetControlPoint(self, *args)

    def GetNumberOfControlPoints(self):
        r"""GetNumberOfControlPoints(self) -> unsigned long"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetNumberOfControlPoints(self)

    def SetInterpolationMethod(self, _arg):
        r"""
        SetInterpolationMethod(self, _arg)

        Parameters
        ----------
        _arg: enum itkContourSpatialObjectEnums::InterpolationMethod const

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_SetInterpolationMethod(self, _arg)

    def GetInterpolationMethod(self):
        r"""GetInterpolationMethod(self) -> itkContourSpatialObjectEnums::InterpolationMethod"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetInterpolationMethod(self)

    def SetInterpolationFactor(self, _arg):
        r"""
        SetInterpolationFactor(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_SetInterpolationFactor(self, _arg)

    def GetInterpolationFactor(self):
        r"""GetInterpolationFactor(self) -> unsigned int"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetInterpolationFactor(self)

    def SetIsClosed(self, _arg):
        r"""
        SetIsClosed(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_SetIsClosed(self, _arg)

    def GetIsClosed(self):
        r"""GetIsClosed(self) -> bool"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetIsClosed(self)

    def IsClosedOn(self):
        r"""IsClosedOn(self)"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_IsClosedOn(self)

    def IsClosedOff(self):
        r"""IsClosedOff(self)"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_IsClosedOff(self)

    def GetOrientationInObjectSpace(self):
        r"""GetOrientationInObjectSpace(self) -> int"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetOrientationInObjectSpace(self)

    def SetAttachedToSlice(self, _arg):
        r"""
        SetAttachedToSlice(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_SetAttachedToSlice(self, _arg)

    def GetAttachedToSlice(self):
        r"""GetAttachedToSlice(self) -> int"""
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_GetAttachedToSlice(self)
    __swig_destroy__ = _itkContourSpatialObjectPython.delete_itkContourSpatialObject3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkContourSpatialObject3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourSpatialObjectPython.itkContourSpatialObject3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkContourSpatialObject3

        Create a new object of the class itkContourSpatialObject3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkContourSpatialObject3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkContourSpatialObject3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkContourSpatialObject3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkContourSpatialObject3 in _itkContourSpatialObjectPython:
_itkContourSpatialObjectPython.itkContourSpatialObject3_swigregister(itkContourSpatialObject3)

